@@ -41,22 +41,6 @@ xyplot(1:10 ~ 1:10,
 
 
 
-## test for POSIXt handling
-
-y <- Sys.time() + 10000 * 1:100
-x <- rnorm(100)
-b <- gl(3,1,100)
-
-xyplot(y ~ x | b)
-xyplot(y ~ x | b, scales = list(relation = "free", rot = 0))
-xyplot(y ~ x | b, scales = "sliced")
-
-
-
-
-
-
-
 
 x <- rnorm(100)
 y <- 2 + 3 * runif(100)
